@@ -1,5 +1,5 @@
 import asyncio
-import contextvars
+import contextvars  # noqa
 import inspect
 import logging
 import typing
@@ -7,15 +7,13 @@ from collections import ChainMap
 from contextlib import AsyncExitStack, AbstractAsyncContextManager, asynccontextmanager, contextmanager
 from json import JSONDecodeError
 from types import FunctionType, CoroutineType
-from typing import List, Union, Any, Callable, Type, Optional, Dict, Sequence, Awaitable, Tuple
+from typing import List, Union, Any, Callable, Type, Optional, Dict, Sequence, Awaitable
 
-# noinspection PyProtectedMember
-from pydantic import DictError
+from pydantic import DictError  # noqa
 from pydantic import StrictStr, ValidationError
 from pydantic import BaseModel, BaseConfig
-from pydantic.fields import ModelField, Field
-# noinspection PyProtectedMember
-from pydantic.main import ModelMetaclass
+from pydantic.fields import ModelField, Field, Undefined
+from pydantic.main import ModelMetaclass  # noqa
 from fastapi.dependencies.models import Dependant
 from fastapi.encoders import jsonable_encoder
 from fastapi.params import Depends
@@ -73,6 +71,8 @@ class Params(fastapi.params.Body):
         min_length: int = None,
         max_length: int = None,
         regex: str = None,
+        example: Any = Undefined,
+        examples: Optional[Dict[str, Any]] = None,
         **extra: Any,
     ):
         super().__init__(
@@ -89,6 +89,8 @@ class Params(fastapi.params.Body):
             min_length=min_length,
             max_length=max_length,
             regex=regex,
+            example=example,
+            examples=examples,
             **extra,
         )
 
@@ -187,7 +189,7 @@ class BaseError(Exception):
     def get_default_description(cls):
         return f"[{cls.CODE}] {cls.MESSAGE}"
 
-    def get_resp(self):
+    def get_resp(self) -> dict:
         error = {
             'code': self.CODE,
             'message': self.MESSAGE,
@@ -465,6 +467,9 @@ def make_request_model(name, module, body_params: List[ModelField]):
         _JsonRpcRequestParams = ModelMetaclass.__new__(ModelMetaclass, '_JsonRpcRequestParams', (BaseModel,), {})
 
         for f in body_params:
+            example = f.field_info.example  # noqa
+            if example is not Undefined:
+                f.field_info.extra['example'] = jsonable_encoder(example)
             _JsonRpcRequestParams.__fields__[f.name] = f
 
         _JsonRpcRequestParams = component_name(f'_Params[{name}]', module)(_JsonRpcRequestParams)
@@ -520,15 +525,28 @@ class JsonRpcContext:
 
     def on_raw_response(
         self,
-        raw_response: dict,
-        exception: Optional[Exception] = None,
-        is_unhandled_exception: bool = False,
+        raw_response: Union[dict, Exception],
     ):
-        raw_response.pop('id', None)
-        if isinstance(self.raw_request, dict) and 'id' in self.raw_request:
-            raw_response['id'] = self.raw_request.get('id')
-        elif 'error' in raw_response:
-            raw_response['id'] = None
+        exception = None
+        is_unhandled_exception = False
+
+        if isinstance(raw_response, Exception):
+            exception = raw_response
+            if isinstance(exception, BaseError):
+                raw_response = exception.get_resp()
+            elif isinstance(exception, HTTPException):
+                raw_response = None
+            else:
+                raw_response = InternalError().get_resp()
+                is_unhandled_exception = True
+
+        if raw_response is not None:
+            raw_response.pop('id', None)
+            if isinstance(self.raw_request, dict) and 'id' in self.raw_request:
+                raw_response['id'] = self.raw_request.get('id')
+            elif 'error' in raw_response:
+                raw_response['id'] = None
+
         self._raw_response = raw_response
         self.exception = exception
         self.is_unhandled_exception = is_unhandled_exception
@@ -572,21 +590,16 @@ class JsonRpcContext:
     async def _handle_exception(self, reraise=True):
         try:
             yield
-        except Exception as exc:
-            if exc is not self.exception:
+        except Exception as exception:
+            if exception is not self.exception:
                 try:
-                    resp, is_unhandled_exception = await self.entrypoint.handle_exception_to_resp(
-                        exc, log_unhandled_exception=False,
-                    )
+                    resp = await self.entrypoint.handle_exception(exception)
                 except Exception as exc:
-                    # HTTPException
-                    self._raw_response = None
-                    self.exception = exc
-                    self.is_unhandled_exception = True
-                    raise
-                self.on_raw_response(resp, exc, is_unhandled_exception)
-            if reraise:
-                raise
+                    self.on_raw_response(exc)
+                else:
+                    self.on_raw_response(resp)
+            if self.exception is not None and (reraise or isinstance(self.exception, HTTPException)):
+                raise self.exception
 
         if self.exception is not None and self.is_unhandled_exception:
             logger.exception(str(self.exception), exc_info=self.exception)
@@ -728,7 +741,7 @@ class MethodRoute(APIRoute):
         try:
             body = await self.parse_body(http_request)
         except Exception as exc:
-            resp, _ = await self.entrypoint.handle_exception_to_resp(exc)
+            resp = await self.entrypoint.handle_exception_to_resp(exc)
             response = self.response_class(content=resp, background=background_tasks)
         else:
             try:
@@ -1013,7 +1026,7 @@ class EntrypointRoute(APIRoute):
         try:
             body = await self.parse_body(http_request)
         except Exception as exc:
-            resp, _ = await self.entrypoint.handle_exception_to_resp(exc)
+            resp = await self.entrypoint.handle_exception_to_resp(exc)
             response = self.response_class(content=resp, background=background_tasks)
         else:
             try:
@@ -1067,13 +1080,7 @@ class EntrypointRoute(APIRoute):
                         shared_dependencies_error=shared_dependencies_error,
                     )
                 )
-
-                # TODO: https://github.com/aio-libs/aiojobs/issues/119
-                job._explicit = True
-                # noinspection PyProtectedMember
-                coro = job._do_wait(timeout=None)
-
-                job_list.append(coro)
+                job_list.append(job.wait())
         else:
             req = req_list[0]
             coro = self.handle_req_to_resp(
@@ -1085,9 +1092,7 @@ class EntrypointRoute(APIRoute):
 
         resp_list = []
 
-        for coro in job_list:
-            resp = await coro
-
+        for resp in await asyncio.gather(*job_list):
             # No response for successful notifications
             has_content = 'error' in resp or 'id' in resp
             if not has_content:
@@ -1216,11 +1221,10 @@ class Entrypoint(APIRouter):
         self.scheduler = await self.scheduler_factory(**(self.scheduler_kwargs or {}))
         return self.scheduler
 
-    async def handle_exception(self, exc):
+    async def handle_exception(self, exc) -> dict:
         raise exc
 
-    async def handle_exception_to_resp(self, exc, log_unhandled_exception=True) -> Tuple[dict, bool]:
-        is_unhandled_exception = False
+    async def handle_exception_to_resp(self, exc) -> dict:
         try:
             resp = await self.handle_exception(exc)
         except BaseError as error:
@@ -1228,11 +1232,9 @@ class Entrypoint(APIRouter):
         except HTTPException:
             raise
         except Exception as exc:
-            if log_unhandled_exception:
-                logger.exception(str(exc), exc_info=exc)
+            logger.exception(str(exc), exc_info=exc)
             resp = InternalError().get_resp()
-            is_unhandled_exception = True
-        return resp, is_unhandled_exception
+        return resp
 
     def bind_dependency_overrides_provider(self, value):
         for route in self.routes:
@@ -1326,4 +1328,4 @@ if __name__ == '__main__':
 
     app.bind_entrypoint(api_v1)
 
-    uvicorn.run(app, port=5000, debug=True, access_log=False)
+    uvicorn.run(app, port=5000, debug=True, access_log=False)  # noqa
